@@ -4,23 +4,24 @@
 #' @param x Object of class \emph{SpatialPoints} or \emph{SpatialPointsDataFrame}.
 #' @param z Object of class \emph{Date}, \emph{POSIXlt} or \emph{POSIXct} with the observation time of \emph{x}.
 #' @param y Object of class \emph{RasterLayer}, \emph{RasterStack} or \emph{RasterBrick}.
+#' @param preserve.revisits Logical. Should the function preserve revisit patterns?
 #' @param derive.raster Should a \emph{RasterLayer} with the total time per pixel be provided?
 #' @importFrom raster crs cellFromXY rasterize
 #' @importFrom sp SpatialPointsDataFrame
 #' @seealso \code{\link{sampleMove}} \code{\link{moveSeg}}
 #' @return A \emph{list} object.
-#' @details {Translates (\emph{x}) into pixel coordinates within a reference raster (\emph{y}). The function
-#' identifies temporal segments corresponding to groups of consecutive observations within the same pixel. In this process, revisits
-#' to recorded pixels are preserved. Once the segments are identified, the function derives mean x and y
-#' coordinates for each of them and evaluates the time spent within each pixel. The function reports on
-#' the start and end timestamps, the mean timestamp and the elapsed time. The output of the function
-#' consists of:
+#' @details {Translates (\emph{x}) into pixel coordinates within a reference raster (\emph{y}). The
+#' function identifies temporal segments corresponding to groups of consecutive observations within
+#' the same pixel. In this process, revisits to recorded pixels are preserved. Once the segments are
+#' identified, the function derives mean x and y coordinates for each of them and evaluates the time
+#' spent within each pixel. The function reports on the start and end timestamps and the elapsed time.
+#' If \emph{preserve.revisits} is FALSE, the function will then summarize the output on a pixel level
+#' summing the time spent at each pixel. Additionally, if \emph{derive.raster} is TRUE, the function
+#' will derive a \emph{RasterLayer} with the same configuration as \emph{y} depicting the the total
+#' amount of time spent per pixel. The output of the function consists of:
 #' \itemize{
-#' \item{\emph{points} - Shapefile with reduced sample set and its corresponding temporal information.}
-#' \item{\emph{total.time} - Raster showing the total time spent at each pixel (if \emph{derive.raster} is TRUE).}
-#' \item{\emph{indices} - Indices for each sample in \emph{x} showing which samples were aggregated.}}
-#'
-#' }
+#' \item{\emph{points} - \emph{SpatialPointsDataFrame} with the reduced sample set.}
+#' \item{\emph{total.time} - \emph{RasterLayer} depicting the total time spent at each pixel.}}}
 #' @examples {
 #'
 #'  require(raster)
@@ -36,14 +37,14 @@
 #'  format="%Y/%m/%d %H:%M:%S")
 #'
 #'  # reduce amount of samples
-#'  move.reduce <- moveReduce(shortMove, r, z)
+#'  move.reduce <- moveReduce(shortMove, r, z, derive.raster=TRUE)
 #'
 #' }
 #' @export
 
 #----------------------------------------------------------------------------------------------------------#
 
-moveReduce <- function(x, y, z, derive.raster=FALSE) {
+moveReduce <- function(x, y, z, preserve.revisits=TRUE, derive.raster=FALSE) {
 
 #----------------------------------------------------------------------------------------------------------#
 # 1. check input variables
@@ -62,7 +63,7 @@ moveReduce <- function(x, y, z, derive.raster=FALSE) {
   if (crs(x)@projargs!=crs(y)@projargs) {stop('"x" and "edata" have different projections')}
 
 #----------------------------------------------------------------------------------------------------------#
-# 2. identify segments
+# 2. identify segments for each temporal window
 #----------------------------------------------------------------------------------------------------------#
 
   # convert x to single pixels
@@ -70,6 +71,7 @@ moveReduce <- function(x, y, z, derive.raster=FALSE) {
   x <- x[os,]
   z <- z[os]
   sp <- cellFromXY(y, x@coords)
+  up <- unique(sp)
 
   rm(os)
 
@@ -81,18 +83,28 @@ moveReduce <- function(x, y, z, derive.raster=FALSE) {
   rm(pd)
 
   # estimate
-  df <- do.call(rbind, lapply(1:max(sg), function(s) {
+  odf <- do.call(rbind, lapply(1:max(sg), function(s) {
     ind <- which(sg==s)
+    pp <- sp[ind[1]]
     mx <- median(x@coords[ind,1])
     my <- median(x@coords[ind,2])
     s.time <- z[ind[1]]
     e.time <- z[ind[length(ind)]]
     d.time <- as.numeric(difftime(e.time, s.time, units='mins'))
-    return(data.frame(x=mx, y=my, start.time=s.time, end.time=e.time, diff.time=d.time, segment.id=s))}))
-  colnames(df) <- c("x", "y", "Timeststamp (start)", "Timeststamp (end)", "Elapsed time (minutes)", "Segment ID")
+    return(data.frame(x=mx, y=my, pos=pp, start.time=s.time, end.time=e.time, elapsed.time=d.time, segment.id=s))}))
+
+  # if preserve.revisits is FALSE, reduce to unique pixels
+  if (!preserve.revisits) {
+    odf <- do.call(rbind, lapply(unique(odf$pos), function(p) {
+      i <- which(up==p)
+      xy <- xyFromCell(y, p)
+      return(data.frame(x=xy[1], y=xy[2], pos=p, start.time=min(odf$start.time[i]),
+                        end.time=max(odf$end.time[i]), elapsed.time=sum(odf$elapsed.time[i])))}))
+
+  }
 
   # build statistic shapefile
-  r.shp <- SpatialPointsDataFrame(df[,1:2], df, proj4string=crs(x))
+  r.shp <- SpatialPointsDataFrame(odf[,c("x","y")], odf, proj4string=crs(x))
 
 #----------------------------------------------------------------------------------------------------------#
 # 3. derive single raster
@@ -101,11 +113,11 @@ moveReduce <- function(x, y, z, derive.raster=FALSE) {
   if (derive.raster) {
 
     # find cell positions of reduced sample set
-    sp <- cellFromXY(y, df[,c("x", "y")])
+    sp <- cellFromXY(y, odf[,c("x", "y")])
     up <- unique(sp)
 
     # estimate time sum per cell
-    t.sum <- sapply(up, function(p) {sum(df$'Elapsed time (minutes)'[which(sp==p)], na.rm=TRUE)})
+    t.sum <- sapply(up, function(p) {sum(odf$elapsed.time[which(sp==p)], na.rm=TRUE)})
 
     # build raster
     t.sum.r <- rasterize(xyFromCell(y, up), y, t.sum)
@@ -116,7 +128,11 @@ moveReduce <- function(x, y, z, derive.raster=FALSE) {
 # 4. build output
 #----------------------------------------------------------------------------------------------------------#
 
-  return(list(points=r.shp, total.time=t.sum.r, indices=sg))
+  return(list(points=r.shp, total.time=t.sum.r))
+
+
+
+
 
 }
 
